Light-weight tight-binding framework
====================================

This pages describe the usage and functionality of `tblite`_ tight-binding framework.
The *tblite* project aims to provide an efficent and uniform interface to the (extended) tight-binding Hamiltonians.

.. important::

   This project does not provide a complete atomistic simulation environment, but the tools to build one.
   If you are looking for a simulation environment that provides the functionality available in *tblite*, checkout the :ref:`available integrations <integration>`.

.. warning::

   The current state of this project should be considered as *highly experimental*.


.. _tblite: https://github.com/awvwgk/tblite

.. toctree::

   Installation <installation>
   Tutorials <tutorial/index>
   Integrations <users/index>
   Specification <spec/index>
   API <api/index>
